@@ -1,10 +1,11 @@
 package CatalystX::Features::Backend;
 {
-  $CatalystX::Features::Backend::VERSION = '0.24';
+  $CatalystX::Features::Backend::VERSION = '0.25';
 }
 use Class::MOP ();
 use Moose;
 use Path::Class;
+use Module::Runtime qw(use_module);
 use Carp;
 
 has 'include_path'  => ( is => 'rw', isa => 'ArrayRef' );
@@ -34,7 +35,7 @@ sub init {
             $self->feature_class( $feature_class );
 
             # init feature
-            Class::MOP::load_class( $feature_class );
+            use_module( $feature_class );
             my $feature = $feature_class->new(
                 {
                     path    => "$feature_path",
@@ -135,7 +136,7 @@ CatalystX::Features::Backend - All the dirty work is done here
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
